from _typeshed import Incomplete
from typing import Any, ClassVar

from .._distutils.command import build_py as orig

def make_writable(target) -> None: ...

class build_py(orig.build_py):
    editable_mode: ClassVar[bool]
    package_data: Any
    exclude_package_data: Any
    def finalize_options(self) -> None: ...
    def run(self) -> None: ...
    data_files: Any
    def __getattr__(self, attr: str): ...
    def build_module(self, module, module_file, package): ...
    def get_data_files_without_manifest(self) -> list[tuple[Incomplete, Incomplete, Incomplete, list[Incomplete]]]: ...
    def find_data_files(self, package, src_dir): ...
    def build_package_data(self) -> None: ...
    manifest_files: Any
    def get_output_mapping(self) -> dict[str, str]: ...
    def analyze_manifest(self) -> None: ...
    def get_data_files(self) -> None: ...
    def check_package(self, package, package_dir): ...
    packages_checked: Any
    def initialize_options(self) -> None: ...
    def get_package_dir(self, package): ...
    def exclude_data_files(self, package, src_dir, files): ...

def assert_relative(path): ...



from _typeshed import Incomplete

from ..cmd import Command

class sdist(Command):
    description: str
    def checking_metadata(self): ...
    user_options: Incomplete
    boolean_options: Incomplete
    help_options: Incomplete
    negative_opt: Incomplete
    READMES: Incomplete
    template: Incomplete
    manifest: Incomplete
    use_defaults: int
    prune: int
    manifest_only: int
    force_manifest: int
    formats: Incomplete
    keep_temp: int
    dist_dir: Incomplete
    archive_files: Incomplete
    metadata_check: int
    owner: Incomplete
    group: Incomplete
    def initialize_options(self) -> None: ...
    def finalize_options(self) -> None: ...
    filelist: Incomplete
    def run(self) -> None: ...
    def check_metadata(self) -> None: ...
    def get_file_list(self) -> None: ...
    def add_defaults(self) -> None: ...
    def read_template(self) -> None: ...
    def prune_file_list(self) -> None: ...
    def write_manifest(self) -> None: ...
    def read_manifest(self) -> None: ...
    def make_release_tree(self, base_dir, files) -> None: ...
    def make_distribution(self) -> None: ...
    def get_archive_files(self): ...
